Setting Up
==========

Installing etlTest is as simple as running::

    $ pip install etlTest

All the requirements will be installed and etlTest is ready to be used.

If you wish to install etlTest manually instead of via ``pip``, there are two main options:

* `GitHub <https://github.com/OpenDataAlex/etlTest/archive/dev.zip>`_
* `PyPi <https://pypi.python.org/pypi/etlTest>`_

If going the manual install route, all requirements can be installed by running::

    $ cd <where_etlTest_is_downloaded_and_extracted>
    $ tox

All of etlTest's own unit tests will run once the requirements are installed.  If everything passes, you are good to go.